@@ -160,7 +160,7 @@ static int erase_and_write(loff_t ofs, unsigned char *data,
 	er.start = ofs;
 	er.length = meminfo.erasesize;
 
-	ret = erase(fd, er.length, er.start);
+	ret = erase(fd, er.length, er.start, ERASE_TO_WRITE);
 	if (ret < 0) {
 		perror("\nerase");
 		printf("Could't not erase flash at 0x%08llx length 0x%08llx.\n",
