@@ -16,19 +16,13 @@
 #define __K3_UART_BASE(soc, num) soc##_UART##num##_BASE
 #define K3_UART_BASE(soc, num) __K3_UART_BASE(soc, num)
 
-static inline uint8_t debug_ll_read_reg(int reg)
+static inline uint8_t debug_ll_read_reg(void __iomem *base, int reg)
 {
-	void __iomem *base = (void *)K3_UART_BASE(K3_DEBUG_SOC,
-					CONFIG_DEBUG_K3_UART_PORT);
-
 	return readb(base + (reg << 2));
 }
 
-static inline void debug_ll_write_reg(int reg, uint8_t val)
+static inline void debug_ll_write_reg(void __iomem *base, int reg, uint8_t val)
 {
-	void __iomem *base = (void *)K3_UART_BASE(K3_DEBUG_SOC,
-					CONFIG_DEBUG_K3_UART_PORT);
-
 	writeb(val, base + (reg << 2));
 }
 
@@ -41,7 +35,10 @@ static inline void debug_ll_init(void)
 
 static inline void PUTC_LL(int c)
 {
-	debug_ll_ns16550_putc(c);
+	void __iomem *base = (void *)K3_UART_BASE(K3_DEBUG_SOC,
+					CONFIG_DEBUG_K3_UART_PORT);
+
+	debug_ll_ns16550_putc(base, c);
 }
 
 #endif
